@@ -1,7 +1,7 @@
 import time
 from typing import List, Tuple, Optional
 
-from selenium.common.exceptions import NoSuchElementException, TimeoutException
+from selenium.common.exceptions import NoSuchElementException, TimeoutException, WebDriverException
 from selenium.webdriver import ActionChains
 from selenium.webdriver.common.by import By
 from selenium.webdriver.remote.webdriver import WebElement
@@ -765,6 +765,15 @@ class Element:
         """ The current instance of `py` that found this element. """
         return self._py
 
+    def css_value(self, property_name: str):
+        """ Gets the CSS Value of this element given the css_name. """
+        self.py.log.info(f'  [STEP] .css_value() - Get a CSS Value given the property: ``{property_name}``')
+        try:
+            return self.webelement.value_of_css_property(property_name)
+        except WebDriverException:
+            self.py.log.warning(f'Property Name: ``{property_name}`` is invalid or not found.')
+            return None
+
     def tag_name(self) -> str:
         """ Gets the tag name of this element. """
         tag_name = self.webelement.tag_name
@@ -839,10 +848,7 @@ class Element:
             `ValueError` if element is not a checkbox or radio button
         """
         type_ = self.webelement.get_attribute('type')
-        if type_ != 'checkbox':
-            pass
-
-        if type_ != 'radio':
+        if type_ != 'checkbox' and type_ != 'radio':
             raise ValueError('Element is not a checkbox or radio button.')
 
         self.py.log.info(f'  [STEP] Check if this checkbox or radio button element is checked')
